@@ -11,8 +11,7 @@ from datetime import datetime, timedelta
 
 ALERTS_TABLE = 'alerts.items'
 ALERTS_CONFIGS_TABLE = 'alerts.config'
-METRICS_TIMESERIES_TABLE = 'metrics.ts'
-TEST_METRICS_TABLE = 'test.metrics.ts'
+METRICS_TIMESERIES_TABLE = 'metrics.details'
 LOGS_METRICS_FETCHING_TABLE = 'logs.cloud_metric_fetching'
 
 ############ ALERTS ###########################
@@ -48,7 +47,7 @@ def insert_alert(alert_id, metric_id, org_id, app_id, team_id, assigned_to, star
 
 def get_alert_item_by_key(anom_id, dynamodb):
   key_dict = {
-    "alert_id" : anom_id, 
+    "alert_id" : anom_id,
   }
   alert_item = get_item(key_dict, ALERTS_TABLE, dynamodb)
   return alert_item
@@ -65,10 +64,10 @@ def update_alert_with_related_anomalies(alert_id,start_time, corr_anoms_dict, re
     'alert_id' : alert_id,
     'start_time' : start_time,
   }
-  
+
   update_item(key_dict, update_expression, expression_attr_values, ALERTS_TABLE, dynamodb)
 
-  return True 
+  return True
 
 def terminate_alert(alert_id,start_time, end_timestamp, dynamodb):
   update_expression = "set end_timestamp=:e"
@@ -79,41 +78,44 @@ def terminate_alert(alert_id,start_time, end_timestamp, dynamodb):
     'alert_id' : alert_id,
     'start_time' : start_time,
   }
-  
+
   update_item(key_dict, update_expression, expression_attr_values, ALERTS_TABLE, dynamodb)
 
-  return True 
+  return True
 
 
 ############ METRICS ##########################
 #create new metric_timeseries item for current day
-def create_metric(metric_id, date_bucket, metric_name, provider, namespace,
-  agent, org_id, app_id, alignment, groupby, dimensions, data_points_list, dynamodb):
+#TODO add unit to create metric
+def create_metric(id, name, provider, namespace, region_name,
+  agent, org_id, component_id, alignment, dimension_name, dimension_value,
+  description, is_active, dynamodb):
   '''
   create_metric(
-    metric_id = "test1", date_bucket = "2020-10-02", metric_name = "error_rate",
+    id = "test1", name = "error_rate",
     provider = "aws", namespace = "dynamodb", agent = "CloudWatch", org_id = "test",
-    app_id = "app1", alignment = "Sum",
-    dimensions = [{"Name": "TableName", "Value": "alerts.config"}],
-    last = 1535530432, data_points_list = [
-      { 'val': 55, 'time' : 1535530430}, 
-      { 'val': 56, 'time': 1535530432}], dynamodb=dynamodb
+    app_id = None, alignment = "Sum",
+    dimensions = [{"name": "TableName", "value": "alerts.config"}],
+    description = "bla bla", is_active = True, period = 60
   )
   '''
   metric_dict = {
-    "metric_id" : metric_id, 
-    "date_bucket" : date_bucket,
-    "metric_name" : metric_name,
-    "provider" : provider,
-    "namespace" : namespace,
-    "agent" : agent,
-    "orgId" : org_id,
-    "appId" : app_id, 
-    "metric_alignment" : alignment,
-    "dimensions": dimensions,
-    "data_points_list" : data_points_list
+    "id": id,
+    "name": name,
+    "provider": provider,
+    "namespace": namespace,
+    "region_name": region_name,
+    "agent": agent,
+    "org_id": org_id,
+    "component_id": component_id,
+    "alignment": alignment,
+    "dimension_value": dimension_value,
+    "dimension_name": dimension_name,
+    "description": description,
+    "is_active": is_active
   }
 
+
   #print(alert_dict)
   response = put_item(metric_dict, METRICS_TIMESERIES_TABLE, dynamodb)
   return response
@@ -126,7 +128,7 @@ def chunks(lst, n):
 
 def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
   #convert list of metric objects into list of metric dicts
-  
+
   #print('Size of {}:'.format(metric_object.get_metric_name()))
   #print(sys.getsizeof(json.dumps(metric_object.to_dict())))
   date = datetime.today()
@@ -138,11 +140,11 @@ def batch_insert_metric_objects(list_of_metric_objects, dynamodb):
       curr_metric = metric_obj.to_dict()
       curr_metric['date_bucket'] = date
       metric_list.append(curr_metric)
-    batch_insert(metric_list, TEST_METRICS_TABLE, dynamodb)
+    batch_insert(metric_list, METRICS_TIMESERIES_TABLE, dynamodb)
 
 def batch_insert_metric_details_objects(list_of_metric_objects, dynamodb):
   #convert list of metric objects into list of metric dicts
-  
+
   #print('Size of {}:'.format(metric_object.get_metric_name()))
   #print(sys.getsizeof(json.dumps(metric_object.to_dict())))
   date = datetime.today()
@@ -154,7 +156,7 @@ def batch_insert_metric_details_objects(list_of_metric_objects, dynamodb):
       curr_metric = metric_obj.to_dict()
       #decide which are going to be the key attrs
       metric_list.append(curr_metric)
-    batch_insert(metric_list, TEST_METRICS_TABLE, dynamodb)
+    batch_insert(metric_list, METRICS_TIMESERIES_TABLE, dynamodb)
 
 def get_metric_details(metric_id, dynamodb):
   date = datetime.today() - timedelta(days=1)
@@ -171,7 +173,7 @@ def get_metric_details(metric_id, dynamodb):
 def get_metric_item_by_key(metric_id, curr_date, dynamodb):
   #get_metric_item_by_key(123, '2020-09-10')
   key_dict = {
-    "metric_id" : metric_id, 
+    "metric_id" : metric_id,
     "date_bucket" : str(curr_date)
   }
 
@@ -191,22 +193,22 @@ def scan_metrics_by_encrypted_id(anom_alarm_id, dynamodb):
 def query_alerts_configs_by_key(metric_id, dynamodb):
   key_condition = Key('metric_id').eq(metric_id)
   alerts_configs_list = query_by_key(key_condition, ALERTS_CONFIGS_TABLE, dynamodb)
-  return alerts_configs_list  
+  return alerts_configs_list
 
-def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_direction, description, 
+def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_direction, description,
   duration, duration_unit, rule_dict, recipients_list, owner_dict, dynamodb):
   '''
   insert_alert_config(
     metric_id = "metric1245", alert_title = "Anomaly by Cluster", severity = "critical",
     alert_type = "anomaly", alert_direction = "spikes/drops", description = "Relevant to Play Store billing user journey",
     duration= 12, duration_unit = "hours", rule_dict = {}, recipients_list = [{
-      "channel" : "webhook", 
+      "channel" : "webhook",
       "contact" : "j.velez2210@gmail.com"
       },{
         "channel" : "slack",
         "contact" : "j.velez2210@gmail.com"
       }
-    ], 
+    ],
     owner_dict = {
       "user_id" : "user12341",
       "user_name" : "João Tótó",
@@ -214,11 +216,11 @@ def insert_alert_config(metric_id, alert_title, severity, alert_type, alert_dire
   )
   '''
   alert_dict = {
-    "metric_id" : metric_id, 
+    "metric_id" : metric_id,
     "alert_title" : alert_title,
-    "severity" : severity, 
+    "severity" : severity,
     "alert_type" : alert_type,
-    "alert_direction" : alert_direction, 
+    "alert_direction" : alert_direction,
     "description" : description,
     "duration" : duration,
     "duration_unit" : duration_unit,
@@ -238,7 +240,7 @@ def query_most_recent_metric_fetching_log(component_id, dynamodb):
   '''
   #TODO Insert a greater than last_fetched_ts condition to prevent the query to go too far in time
   #& Key('last_fetched_ts').between(start_ts, end_ts)
-  key_condition = Key('component_id').eq(component_id) 
+  key_condition = Key('component_id').eq(component_id)
   logs_list = query_by_key_min_max(key_condition, LOGS_METRICS_FETCHING_TABLE, False, dynamodb)
   if len(logs_list) > 0:
     return logs_list[0]['last_fetched_ts']
@@ -248,24 +250,24 @@ def query_most_recent_metric_fetching_log(component_id, dynamodb):
 ############## EXAMPLES #####################
 def update_values_in_dict_attr():
   '''
-  dynamo = boto3.resource('dynamodb')  
-    tbl = dynamo.Table('<TableName>')  
+  dynamo = boto3.resource('dynamodb')
+    tbl = dynamo.Table('<TableName>')
 
-    result = tbl.update_item(  
-        Key={  
-            "game_id": game_id  
-        },  
-        UpdateExpression="SET players.#player_id.score = :score_val",  
-        ExpressionAttributeNames={  
-            "#player_id": player_id  
-        },  
-        ExpressionAttributeValues={  
-            ":score_val": score_val  
-        }  
+    result = tbl.update_item(
+        Key={
+            "game_id": game_id
+        },
+        UpdateExpression="SET players.#player_id.score = :score_val",
+        ExpressionAttributeNames={
+            "#player_id": player_id
+        },
+        ExpressionAttributeValues={
+            ":score_val": score_val
+        }
     )
   '''
   return True
 
 
 ########## Function Calls ##########################
-#query_most_recent_metric_fetching_log('prd_db')
\ No newline at end of file
+#query_most_recent_metric_fetching_log('prd_db')
